"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runDepsStatusCheck = runDepsStatusCheck;
exports.createInstallArgs = createInstallArgs;
const error_1 = require("@pnpm/error");
const exec_pnpm_cli_runner_1 = require("@pnpm/exec.pnpm-cli-runner");
const logger_1 = require("@pnpm/logger");
const deps_status_1 = require("@pnpm/deps.status");
const enquirer_1 = require("enquirer");
async function runDepsStatusCheck(opts) {
    // the following flags are always the default values during `pnpm run` and `pnpm exec`,
    // so they may not match the workspace state after `pnpm install --production|--no-optional`
    const ignoredWorkspaceStateSettings = ['dev', 'optional', 'production'];
    opts.ignoredWorkspaceStateSettings = ignoredWorkspaceStateSettings;
    const { upToDate, issue, workspaceState } = await (0, deps_status_1.checkDepsStatus)(opts);
    if (upToDate)
        return;
    const command = ['install', ...createInstallArgs(workspaceState?.settings)];
    const install = exec_pnpm_cli_runner_1.runPnpmCli.bind(null, command, { cwd: opts.dir });
    switch (opts.verifyDepsBeforeRun) {
        case 'install':
            install();
            break;
        case 'prompt': {
            const confirmed = await (0, enquirer_1.prompt)({
                type: 'confirm',
                name: 'runInstall',
                message: `Your "node_modules" directory is out of sync with the "pnpm-lock.yaml" file. This can lead to issues during scripts execution.

Would you like to run "pnpm ${command.join(' ')}" to update your "node_modules"?`,
                initial: true,
            });
            if (confirmed.runInstall) {
                install();
            }
            break;
        }
        case 'error':
            throw new error_1.PnpmError('VERIFY_DEPS_BEFORE_RUN', issue ?? 'Your node_modules are out of sync with your lockfile', {
                hint: 'Run "pnpm install"',
            });
        case 'warn':
            (0, logger_1.globalWarn)(`Your node_modules are out of sync with your lockfile. ${issue}`);
            break;
    }
}
function createInstallArgs(opts) {
    const args = [];
    if (!opts)
        return args;
    const { dev, optional, production } = opts;
    if (production && !dev) {
        args.push('--production');
    }
    else if (dev && !production) {
        args.push('--dev');
    }
    if (!optional) {
        args.push('--no-optional');
    }
    return args;
}
//# sourceMappingURL=runDepsStatusCheck.js.map